Index: chrome/browser/chromeos/status/power_menu_button.h |
diff --git a/chrome/browser/chromeos/status/power_menu_button.h b/chrome/browser/chromeos/status/power_menu_button.h |
index 7cc55209db1f81298b2275d83b6132d39ecc96dc..abf758acb995d5d8f28fd26f80ca4dde29f04f61 100644 |
--- a/chrome/browser/chromeos/status/power_menu_button.h |
+++ b/chrome/browser/chromeos/status/power_menu_button.h |
@@ -12,6 +12,10 @@ |
#include "views/controls/menu/menu_2.h" |
#include "views/controls/menu/view_menu_delegate.h" |
+namespace base { |
+class TimeDelta; |
+} |
+ |
class SkBitmap; |
namespace chromeos { |
@@ -64,8 +68,8 @@ class PowerMenuButton : public StatusAreaButton, |
// This method will draw the |icon| in the appropriate place on the |canvas|. |
void DrawPowerIcon(gfx::Canvas* canvas, SkBitmap icon); |
- // Update the power icon depending on the power status. |
- void UpdateIcon(); |
+ // Update the power icon and menu label info depending on the power status. |
+ void UpdateIconAndLabelInfo(); |
// The number of power images. |
static const int kNumPowerImages; |
@@ -73,6 +77,14 @@ class PowerMenuButton : public StatusAreaButton, |
// The power menu. |
views::Menu2 power_menu_; |
+ // Stored data gathered CrosLibrary::PowerLibrary. |
+ bool battery_is_present_; |
+ bool line_power_on_; |
+ bool battery_fully_charged_; |
+ double battery_percentage_; |
+ base::TimeDelta battery_time_to_full_; |
+ base::TimeDelta battery_time_to_empty_; |
+ |
// The currently showing icon bitmap id. |
int icon_id_; |